birnbaum_importance: Birnbaum reliability importance

View source: R/generics.R

birnbaum_importanceR Documentation

Birnbaum reliability importance

Description

The Birnbaum importance of component j at component reliabilities p is ⁠dR/dp_j = R(p with p_j = 1) - R(p with p_j = 0)⁠. Measures how much the system reliability changes if j moves between certain failure and certain success (and, by monotonicity, the rate of change at any intermediate p_j).

Usage

birnbaum_importance(x, j, p)

## S3 method for class 'dist_structure'
birnbaum_importance(x, j, p)

Arguments

x

A dist_structure object.

j

Component index.

p

Numeric vector of length ncomponents(x) or a scalar in ⁠[0, 1]⁠.

Value

Numeric scalar in ⁠[0, 1]⁠.


dist.structure documentation built on May 13, 2026, 1:07 a.m.