min_paths: Minimal path sets

View source: R/generics.R

min_paths.dist_structureR Documentation

Minimal path sets

Description

Returns the minimal subsets of 1:m whose joint functioning is sufficient for the system to function. min_paths and phi() are dual primitives in the dist_structure protocol: providing one is enough, the other has an enumerative default.

Usage

## S3 method for class 'dist_structure'
min_paths(x)

min_paths(x)

Arguments

x

A dist_structure object.

Value

A list of integer vectors.

See Also

phi() for the dual primitive; min_cuts() for the dual topology query (minimal subsets whose joint failure causes system failure).


dist.structure documentation built on May 13, 2026, 1:07 a.m.