| vesely_fussell_importance | R Documentation |
Probability that at least one minimal cut set containing j has all
its components failed, given the system has failed by time t.
Computed exactly via inclusion-exclusion over subsets of cuts that
contain j.
vesely_fussell_importance(x, j, t)
## S3 method for class 'dist_structure'
vesely_fussell_importance(x, j, t)
x |
A dist_structure object. |
j |
Component index. |
t |
Scalar time. |
Numeric scalar in [0, 1].
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.