| birnbaum_importance | R Documentation |
The Birnbaum importance of component j at component reliabilities
p is dR/dp_j = R(p with p_j = 1) - R(p with p_j = 0). Measures
how much the system reliability changes if j moves between certain
failure and certain success (and, by monotonicity, the rate of
change at any intermediate p_j).
birnbaum_importance(x, j, p)
## S3 method for class 'dist_structure'
birnbaum_importance(x, j, p)
x |
A dist_structure object. |
j |
Component index. |
p |
Numeric vector of length |
Numeric scalar in [0, 1].
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.