View source: R/coherent_dist.R
| kofn_dist | R Documentation |
A k-out-of-n system functions if at least k of its m components
function. Equivalent to the (m - k + 1)-th order statistic of
component lifetimes.
kofn_dist(k, components)
k |
Minimum functioning components for system operation (:G). |
components |
List of |
This constructor uses the :G convention: k is the number of
components that must remain functioning for the system to function.
k = 1 is parallel; k = m is series. The companion kofn package
(which depends on dist.structure) uses the :F convention, where
k is the number of failures that trigger system failure; conversion
is k_dist = m - k_kofn + 1. When in doubt, draw a small example:
kofn_dist(k = 2, ...) for m = 3 functions until two of the three
components have failed.
A kofn_dist inheriting from coherent_dist.
order_statistic() for the closely-related order-statistic
parameterization.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.